package tech.nevets.igformatter;

import spark.Request;
import spark.Response;
import spark.Route;

import javax.imageio.ImageIO;
import javax.servlet.MultipartConfigElement;
import javax.servlet.http.Part;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;

public class GenerateRoute implements Route {
    @Override
    public Object handle(Request req, Response res) throws Exception {
        req.attribute("org.eclipse.jetty.multipartConfig", new MultipartConfigElement("./temp"));
        Part part = req.raw().getPart("image");
        if (part == null) {
            res.status(400);
            res.type("text/plain");
            return "No image uploaded";
        }
        try (InputStream is = part.getInputStream()) {
            BufferedImage img = ImageIO.read(is);
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            String color;
            int width;
            int height;
            int minBorder;
            try {
                color = req.queryParams("color");
                width = Integer.parseInt(req.queryParams("width"));
                height = Integer.parseInt(req.queryParams("height"));
                minBorder = Integer.parseInt(req.queryParams("minBorder"));
            } catch (final Exception e) {
                res.type("plain/text");
                res.status(400);
                return "Error in sent parameters: " + e.getMessage();
            }

            BufferedImage finalImg = Images.renderImage(img, color, width, height, minBorder);
            if (finalImg == null) {
                res.type("text/plain");
                res.status(400);
                return "Dimensions too large, max 8000x6000";
            }

            ImageIO.write(finalImg, "png", baos);

            res.type("image/png");
            return baos.toByteArray();
        } catch (Exception e) {
            res.type("plain/text");
            res.status(500);
            return "Error creating image: " + e.getMessage();
        }
    }
}
