package tech.nevets.igformatter;

import java.awt.*;
import java.awt.image.BufferedImage;

public class Images {
    public static BufferedImage renderImage(BufferedImage img, String color, int totalWidth, int totalHeight, int minBorder) {
        if (totalWidth > 8000 || totalHeight > 6000) {
            System.out.println("Input too large");
            return null;
        }

        BufferedImage image = generateBackground(color, totalWidth, totalHeight);
        Graphics2D g = image.createGraphics();

        int width;
        int height;
        int xPos;
        int yPos;

        int oldWidth = img.getWidth();
        int oldHeight = img.getHeight();
        if (oldWidth > oldHeight) {
            width = (totalWidth - (minBorder * 2));
            height = (width * oldHeight) / oldWidth;
            xPos = minBorder;
            yPos = (totalHeight - height) / 2;
        } else if (oldHeight > oldWidth) {
            height = (totalWidth - (minBorder * 2));
            width = (oldWidth * height) / oldHeight;
            xPos = (totalWidth - width) / 2;
            yPos = minBorder;
        } else {
            width = (totalWidth - (minBorder * 2));
            height = (totalHeight - (minBorder * 2));
            xPos = minBorder;
            yPos = minBorder;
        }

        g.drawImage(resizeImage(img, width, height), xPos, yPos, width, height, null);
        g.dispose();

        return image;
    }

    private static BufferedImage resizeImage(BufferedImage rawImage, int width, int height) {
        BufferedImage resizedImage = new BufferedImage(width, height, BufferedImage.TYPE_INT_ARGB);
        Graphics2D g = resizedImage.createGraphics();
        g.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
        g.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
        g.drawImage(rawImage, 0, 0, width, height, null);
        g.dispose();
        return resizedImage;
    }

    private static int hexToInt(String hex) {
        return Integer.parseInt(hex, 16);
    }

    public static BufferedImage generateBackground(String color, int width, int height) {
        BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_ARGB);
        Graphics2D g2d = image.createGraphics();
        g2d.setColor(new Color(hexToInt(color.substring(1))));
        g2d.setPaint(new Color(hexToInt(color.substring(1))));
        g2d.fillRect(0, 0, width, height);
        g2d.dispose();
        return image;
    }
}
